/*
 *  %%% NAME %%%
 *  
 *  Copyright (c) 2010-2013 The MathJax Consortium
 *
 *  Part of the MathJax library.
 *  See http://www.mathjax.org for details.
 * 
 *  Licensed under the Apache License, Version 2.0;
 *  you may not use this file except in compliance with the License.
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 */
%%% MMLorHTML %%%
MathJax.Ajax.Preloading(
%%% FILES %%%
);

MathJax.Hub.Config({"v1.0-compatible":false});

